@@ -11,7 +11,7 @@ use strict;
 use Carp;
 use Data::Table::Text 2017.114 qw(:all);
 use Data::Dump qw(dump);
-our $VERSION = 2017.116;
+our $VERSION = 2017.117;
 
 saveToS3('BinaryHeapArray') if 0;
 
@@ -102,7 +102,7 @@ sub push($$)
  } # push
 
 sub size($)                                                                     # Find the number of elements in the binary heap array
- {my ($array, $element) = @_;                                                   # Array
+ {my ($array) = @_;                                                             # Array
   my $n = 0;                                                                    # Element count, width of current sub array
   my $s = $array->subarray;                                                     # Array of sub arrays
   if ($s and @$s)                                                               # Sub array
@@ -238,7 +238,7 @@ test unless caller;
 
 =head1 Methods
 
-=head2 new()()
+=head2 new()
 
 Create a new binary heap Array
 
@@ -266,23 +266,22 @@ Push a new element on to the top of the array by accumulating the leading full s
   1  $array     Array
   2  $element   element to push
 
-=head2 size($array, $element)
+=head2 size($array)
 
 Find the number of elements in the binary heap array
 
      Parameter  Description
   1  $array     Array
-  2  $element
 
 =head1 Index
 
 Alphabetic list of methods:
 
 L</at :lvalue($array, $index)>
-L</new()()>
+L</new()>
 L</pop($array)>
 L</push($array, $element)>
-L</size($array, $element)>
+L</size($array)>
 
 =head1 Installation
 
